<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="任务名称">
              <el-input maxlength="256" clearable v-model="querys[0].value" placeholder="请输入任务名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="任务类型">
              <el-select clearable v-model="querys[1].value" placeholder="请输入任务类型">
                <el-option v-for="item in taskTypes" :key="item.id" :label="item.label" :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <!-- @click="deleteSelect" -->
          <el-button slot="reference" icon="el-icon-delete" style="margin-left: 10px"
            :disabled="!multipleSelection.length" type="danger">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" :data="tableData" row-key="id" ref="multipleSelection"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" :default-sort="{ prop: 'taskName', order: 'ascending' }"
        @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" :reserve-selection="true"></el-table-column>
        <el-table-column min-width="200" sortable prop="taskName" label="任务名称" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="100" sortable prop="taskType" label="任务类型" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="240" sortable prop="taskClass" label="任务执行类"
          show-overflow-tooltip></el-table-column>
        <el-table-column min-width="120" sortable prop="taskRate&taskRateUnit" label="任务调用频率" show-overflow-tooltip>
          <template #default="scope">
            {{ scope.row.taskRate }}{{ scope.row.taskRateUnit }}
          </template>
        </el-table-column>

        <el-table-column min-width="120" label="操作" fixed="right" prop="operation" show-overflow-tooltip>
          <template #default="scope">
            <el-dropdown split-button @click="startUpJob(scope.row)" @command="toLogQuery(scope.row)" size="small">
              {{
                scope.row.taskStatus === 'NONE'
                  ? '开始'
                  : scope.row.taskStatus === 'NORMAL'
                    ? '暂停'
                    : '开始'
              }}
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item command="waterStation">日志查询</el-dropdown-item>
              </el-dropdown-menu>
            </el-dropdown>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <form-dialog ref="formModal" @reload="reload"></form-dialog>
  </div>
</template>

<script>
import FormDialog from './components/taskFormDialog.vue'
import { TableMixin } from '@/mixins/tableMixin'
import collection from '@/api/device/collection.js'
import req from '@/request.js'
export default {
  name: 'CollectionTask',
  components: {
    FormDialog,
  },
  mixins: [TableMixin],
  data() {
    return {
      querys: [
        {
          group: 'filter',
          operation: 'LIKE',
          property: 'taskName',
          relation: 'AND',
          value: '',
        },
        {
          group: 'filter',
          operation: 'EQUAL',
          property: 'taskType',
          relation: 'AND',
          value: '',
        },
      ],
      total: 0,
      taskClass: '', //任务执行类
      taskRate: null, //任务调用频率
      taskRateUnit: '', //任务调用频率单位(m:分钟，h:小时，d:天，w:周，M:月，Y：年)
      sourceCode: '', //数据源
      sourceTable: '', //源表名
      taskMemo: '', //任务说明
      tableData: [],
      taskTypes: [
        { value: 1, label: '定时任务' },
        { value: 2, label: '非定时任务' },
      ],
      operation: '操作',
      logQuery: '日志查询',
      taskStatus: '', //NONE停止任务 NORMAL运行任务 PAUSED暂停任务
      loading: false,
      multipleSelection: [], // 复选框
      title: '',
    }
  },
  created() { },
  methods: {
    // 获取分页数据
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      collection.listQuery(this.queryParam, (res) => {
        if (res.rows && res.rows.length) {
          this.total = res.total
          this.tableData = this.formatData(res.rows)
        }
        this.$set(this.tableData)
        this.loading = false
      })
    },
    formatData(rows) {
      rows.forEach((item) => {
        this.taskTypes.forEach((type) => {
          if (type.value === item.taskType) {
            item['taskType'] = type.label
          }
        })
      })
      return rows
    },
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    reload() {
      this.loadData(1)
    },
    // 任务启动状态
    startUpJob(row) {
      console.log(row.id)
      let taskId = row.id
      if (row.taskStatus === 'NONE') {
        console.log(row.taskStatus)
        collection.startUpJob(taskId, (res) => {
          if (res.state) {
            console.log(res)
            row.taskStatus = 'NORMAL'
          }
        })
      }
      if (row.taskStatus === 'PAUSED') {
        console.log(row.taskStatus)
        collection.startUpJob(taskId, (res) => {
          if (res.state) {
            console.log(res)
            row.taskStatus = 'NORMAL'
            this.$notify({
              message: '开启成功',
              type: 'success',
              duration: 2000,
            })
          }
        })
      }
      if (row.taskStatus === 'NORMAL') {
        console.log(row.taskStatus)
        collection.stopJob(taskId, (res) => {
          if (res.state) {
            console.log(res)
            row.taskStatus = 'PAUSED'
            this.$notify({
              message: '暂停成功',
              type: 'success',
              duration: 2000,
            })
          }
        })
      }
    },
    // 跳转日志查询
    toLogQuery(row) {
      if (this.$route.path.indexOf('frontPlat') !== -1) {
        this.$router.push({
          name: 'LogQuery',
          query: { id: row.id, taskName: row.taskName },
        })
      } else {
        this.$router.push({
          name: 'LogQueryLink',
          query: { id: row.id, taskName: row.taskName },
        })
      }
    },
    handleDelete() {
      const task = window.context.task
      req.remove(task + '/biz/task/schedulerTask/v1/' + '?ids=' + this.multipleSelection).then(res => {
        this.$notify({
          type: 'success',
          message: '删除成功',
          duration: 2000,
        })
        this.loadData()
      })
    }
  },
}
</script>

<style lang="scss" scoped>
.btn-content {
  display: flex;
}

.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}

.el-select-dropdown__item {
  color: #9a9a9a !important;
}

.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}

.btn-content :first-child {
  margin: 0 0 0 0 !important;
}

// ::v-deep .el-table__body-wrapper::-webkit-scrollbar {
//   width: 6px;
//   height: 15px;
// }
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}

::-webkit-scrollbar {
  background: #fff !important;
}

//滚动条的宽度
::-webkit-scrollbar {
  width: 8px;
  height: 8px;
  background-color: #e4e4e4;
  border-radius: 6px;
}

//滚动条的滑块
::-webkit-scrollbar-thumb {
  background-color: #a1a3a9;
  border-radius: 6px;
}

.bbsl-pagination {
  bottom: 10px !important;
}
</style>
